@@ -12,25 +12,19 @@ sub new {
     bless [] => shift;
 }
 
-sub load_me {
+method load_me {
     $.private_key  = $_ [0] if @_;
     $.simple_key   = $_ [1] if @_ > 1;
     $.settable_key = $_ [2] if @_ > 2;
 }
 
-sub count_keys { # Leave me
+sub count_keys {
    (scalar keys %simple_key,
     scalar keys %private_key,
     scalar keys %settable_key,)
 }
 
-sub DESTROY {
-    $self -> do_something ();
-
-    __DESTROY__;
-}
-
-sub do_something {
+method DESTRUCT {
     1;
 }
 
@@ -41,6 +35,9 @@ __END__
 =head1 HISTORY
 
  $Log: BusyDestroy.pm,v $
+ Revision 1.2  2005/08/26 21:24:45  abigail
+ New, or modified tests
+
  Revision 1.1  2005/02/25 00:24:02  abigail
  First checkin
 
