@@ -10,21 +10,25 @@ our @ISA = qw /Super/;
 has ($.name, $.colour);
 has ($.age, $.key1, $.key2) is rw;
 
-sub base_name {
-    $.name = shift if @_;
+method base_name {
     $.name;
 }
-
-sub base_colour {
-    $.colour = shift if @_;
-    $.colour;
+method set_base_name {
+    $.name = shift;
 }
 
-sub address {
+method base_colour {
+    $.colour;
+}
+method set_base_colour {
+    $.colour = shift;
+}
+
+method address {
     reverse $self -> SUPER::address;
 }
 
-sub set_key2 {
+method my_set_key2 {
     $.key2 = shift;
 }
 
@@ -35,6 +39,9 @@ __END__
 =head1 HISTORY
 
  $Log: LA_Base.pm,v $
+ Revision 1.3  2005/08/26 21:24:45  abigail
+ New, or modified tests
+
  Revision 1.2  2005/03/03 23:32:59  abigail
  Renamed Base.pm and Overload.pm because of case-insensitive filesystems
 
